! MDSBI version 4.1.7 -- Multi-Dimensional Spectral Boundary Integral Code
module mpi_routines

  use constants, only : pin,pr,psav

  implicit none

  integer(pin),parameter :: master=0
  integer(pin),save :: MPI_REAL_PR,MPI_CPLX_PR,MPI_REAL_PSAV
  real(pr),save :: starttime,endtime

contains

  
  subroutine start_mpi

    use constants, only : real4,real8
    use mpi
    
    implicit none

    integer(pin) :: ierr
    
    call MPI_Init(ierr)

    select case(pr)
    case(real4)
       MPI_REAL_PR = MPI_REAL
       MPI_CPLX_PR = MPI_COMPLEX
    case(real8)
       MPI_REAL_PR = MPI_DOUBLE_PRECISION
       MPI_CPLX_PR = MPI_DOUBLE_COMPLEX
    end select
    
    select case(psav)
    case(real4)
       MPI_REAL_PSAV = MPI_REAL
    case(real8)
       MPI_REAL_PSAV = MPI_DOUBLE_PRECISION
    end select
    
    starttime = MPI_WTime()
    
  end subroutine start_mpi


  subroutine finish_mpi

    use mpi

    implicit none

    integer(pin) :: ierr

    endtime = MPI_WTime()

    if (is_master()) then
       write (6,'(a)') ''
       write (6,'(a,g20.10,a)') 'Total MPI time ',endtime-starttime,' s'
    end if

    call MPI_Finalize(ierr)

  end subroutine finish_mpi


  function using_mpi()

    use constants, only : zero
    use mpi

    implicit none

    logical :: using_mpi

    if (MPI_WTime()==zero) then
       using_mpi = .false.
    else
       using_mpi = .true.
    end if

  end function using_mpi


  function nprocs()
    
    use mpi

    implicit none

    integer(pin) :: nprocs

    integer(pin) :: ierr

    call MPI_COMM_SIZE(MPI_COMM_WORLD,nprocs,ierr)

  end function nprocs


  function my_rank()
    
    use mpi

    implicit none

    integer(pin) :: my_rank

    integer(pin) :: ierr
    
    call MPI_COMM_RANK(MPI_COMM_WORLD,my_rank,ierr)

  end function my_rank


  function is_master()
    
    logical :: is_master

    is_master = (my_rank()==master)

  end function is_master


end module mpi_routines
